Crate brush_interactive

Crate brush_interactive 

Library implementing interactive command input and completion for the brush shell.

Structs

InteractiveOptions
Options for interactive shells.
InteractivePrompt
Represents an interactive prompt.
InteractiveShell
Represents an interactive shell that displays prompts, interactively reads user input, etc.
UIOptions
Options for a shell user interface.

Enums

InteractiveExecutionResult
Result of an interactive execution.
ReadResult
Result of a read operation.
ShellError
Represents an error encountered while running or otherwise managing an interactive shell.

Traits

InputBackend
Represents an input backend for reading lines of input.

Type Aliases

ShellRef
A reference-counted, thread-safe reference to a brush_core::Shell.