pub struct InteractiveShell<'a, IB: InputBackend, SE: ShellExtensions> { /* private fields */ }Expand description
Represents an interactive shell that displays prompts, interactively reads user input, etc.
Implementations
Sourceimpl<'a, IB: InputBackend, SE: ShellExtensions> InteractiveShell<'a, IB, SE>
impl<'a, IB: InputBackend, SE: ShellExtensions> InteractiveShell<'a, IB, SE>
Sourcepub fn new(
shell: &ShellRef<SE>,
input: &'a mut IB,
options: &InteractiveOptions,
) -> Result<Self, ShellError>
pub fn new( shell: &ShellRef<SE>, input: &'a mut IB, options: &InteractiveOptions, ) -> Result<Self, ShellError>
Creates a new InteractiveShell wrapping the given shell instance.
Arguments
shell- The shell instance to wrap.input- The input backend to use.options- The user interface options to use.
Sourcepub async fn run_interactively(&mut self) -> Result<(), ShellError>
pub async fn run_interactively(&mut self) -> Result<(), ShellError>
Runs the interactive shell loop, reading commands from standard input and writing results to standard output and standard error. Continues until the shell normally exits or until a fatal error occurs.