Library implementing interactive command input and completion for the brush shell.
Structs
- Interactive
Options - Options for interactive shells.
- Interactive
Prompt - Represents an interactive prompt.
- Interactive
Shell - Represents an interactive shell that displays prompts, interactively reads user input, etc.
- UIOptions
- Options for a shell user interface.
Enums
- Interactive
Execution Result - Result of an interactive execution.
- Read
Result - Result of a read operation.
- Shell
Error - Represents an error encountered while running or otherwise managing an interactive shell.
Traits
- Input
Backend - Represents an input backend for reading lines of input.
Type Aliases
- Shell
Ref - A reference-counted, thread-safe reference to a
brush_core::Shell.